@@ -1,4 +1,20 @@
 
+pipe_impl <- function(pipe_left_arg, pipe_right_arg, pipe_environment) {
+  # force pipe_left_arg, by left-associativity "pipe_left_arg" may be a pipe
+  # sequence itself.
+  # We are not bothering to capture that as a list, just letting
+  # R's calling sequence take us to those pieces.
+  pipe_left_arg <- eval(pipe_left_arg,
+                        envir = pipe_environment,
+                        enclos = pipe_environment)
+  # eval by with pipe_left_arg's value in dot (simulates chaining)
+  assign(".", pipe_left_arg,
+         envir= pipe_environment,
+         inherits= FALSE)
+  eval(pipe_right_arg,
+       envir=pipe_environment,
+       enclos=pipe_environment)
+}
 
 #' Pipe operator ("dot arrow").
 #'
@@ -21,19 +37,6 @@
   pipe_left_arg <- substitute(pipe_left_arg)
   pipe_right_arg <- substitute(pipe_right_arg)
   pipe_environment <- parent.frame()
-  # force pipe_left_arg, by left-associativity "pipe_left_arg" may be a pipe
-  # sequence itself.
-  # We are not bothering to capture that as a list, just letting
-  # R's calling sequence take us to those pieces.
-  pipe_left_arg <- eval(pipe_left_arg,
-            envir = pipe_environment,
-            enclos = pipe_environment)
-  # eval by with pipe_left_arg's value in dot (simulates chaining)
-  assign(".", pipe_left_arg,
-         envir= pipe_environment,
-         inherits= FALSE)
-  eval(pipe_right_arg,
-            envir=pipe_environment,
-            enclos=pipe_environment)
+  pipe_impl(pipe_left_arg, pipe_right_arg, pipe_environment)
 }
 
